# sequana_denovo

**DOI:** [10.5281/zenodo.7335175](https://doi.org/10.5281/zenodo.7335175)

## Available Versions
- **Version 0.0.2**
  - [Download](https://zenodo.org/record/7335176/files/denovo_tools_0.0.2.img)
  - **MD5:** `e9b9fc132ac0aa62e3fc43af5a65fe9f`
  - **DOI:** [10.5281/zenodo.7335176](https://doi.org/10.5281/zenodo.7335176)
  - **Size:** 1679.96 MB
  - **Binaries:** 0 available

## Binaries (7 total)

```prokka quast.py blastn blastp busco spades unicycler```
